@@ -33,14 +33,37 @@ parser_commit_msg_grp = parser_commit.add_mutually_exclusive_group()
 parser_commit_msg_grp.add_argument('message', nargs='*', help="commit message", default='')
 parser_commit_msg_grp.add_argument('-m', nargs=1, help="commit message", default='')
 
+# push
+parser_push = command_subparser.add_parser(
+    'push',
+    help='push commits to remote git and dvc repository'
+)
+parser_push.add_argument('-gr', '--git-remote', help="git remote name, default 'origin'", default="origin")
+parser_push.add_argument('-dr', '--dvc-remote', help="dvc remote name, default 'origin'", default="origin")
+parser_push.add_argument(
+    'branch',
+    help="A git branch that you want to push to (accepts refspec), defaults to current branch",
+    nargs='?'
+)
+# save
+parser_save = command_subparser.add_parser(
+    'save',
+    help='saves all project files to a new version and pushes them to your remote'
+)
+parser_save.add_argument('-gr', '--git-remote', help="git remote name, default 'origin'", default="origin")
+parser_save.add_argument('-dr', '--dvc-remote', help="dvc remote name, default 'origin'", default="origin")
+parser_save.add_argument('message', help="save message")
+
 # argument for log level
 arg_parser.add_argument("-v", "--verbose", help="set log level to DEBUG",
                         action="store_true", default=False)
 
+
 def parse_args(args):
     arguments = vars(arg_parser.parse_args(args=args or ["--help"]))
     return arguments
 
+
 def main(args=None):
     if args is None:
         args = sys.argv[1:]
