@@ -76,5 +76,13 @@ class Run(object):
             # Run commit command stuff
             self.service.commit(message, arguments['yes'])
             return 0
+        elif arguments["command"] == Commands.PUSH.value:
+            # Run push command stuff
+            self.service.push(arguments["git_remote"], arguments["dvc_remote"], arguments["branch"])
+            return 0
+        elif arguments["command"] == Commands.SAVE.value:
+            # Run save command stuff
+            self.service.save(arguments["message"], arguments["git_remote"], arguments["dvc_remote"])
+            return 0
         else:
             raise Exception("Invalid operation")
