@@ -1,8 +1,6 @@
-import argparse
 import subprocess
 from pathlib import Path
 import os
-import sys
 from typing import List, Union, Any
 
 import humanize
@@ -25,7 +23,7 @@ def convert_bytes_to_string(bytes_data: bytes) -> str:
     return bytes_data.decode("utf-8")
 
 
-def execute_command(command: Union[str, List[str]], shell: bool = False, capture_output: bool=True,
+def execute_command(command: Union[str, List[str]], shell: bool = False, capture_output: bool = True,
                     ignorable_return_codes: List[int] = [0]) -> Any:
     if capture_output:
         # capture_output is not available in python 3.6, so using PIPE manually
@@ -54,7 +52,7 @@ def does_file_exist(filename: str) -> bool:
     try:
         import os.path
         return os.path.exists(filename)
-    except Exception as e:
+    except Exception:
         return False
 
 
