@@ -23,11 +23,11 @@ class TestGit(IntegrationTestCase):
         self.git_service.add(".")
         output = execute_command(["git", "status"], capture_output=True)
         assert convert_bytes_to_string(output.stderr) == ""
-        assert f"new file:   git_data/file-0" in convert_bytes_to_string(output.stdout)
-        assert f"new file:   git_data/file-1" in convert_bytes_to_string(output.stdout)
-        assert f"new file:   git_data/file-2" in convert_bytes_to_string(output.stdout)
-        assert f"new file:   git_data/file-3" in convert_bytes_to_string(output.stdout)
-        assert f"new file:   git_data/file-4" in convert_bytes_to_string(output.stdout)
+        assert "new file:   git_data/file-0" in convert_bytes_to_string(output.stdout)
+        assert "new file:   git_data/file-1" in convert_bytes_to_string(output.stdout)
+        assert "new file:   git_data/file-2" in convert_bytes_to_string(output.stdout)
+        assert "new file:   git_data/file-3" in convert_bytes_to_string(output.stdout)
+        assert "new file:   git_data/file-4" in convert_bytes_to_string(output.stdout)
 
     def test_add_one(self):
         self.git_service.init()
@@ -35,7 +35,7 @@ class TestGit(IntegrationTestCase):
         self.git_service.add("git_data/file-0")
         output = execute_command(["git", "status"], capture_output=True)
         assert convert_bytes_to_string(output.stderr) == ""
-        assert f"new file:   git_data/file-0" in convert_bytes_to_string(output.stdout)
+        assert "new file:   git_data/file-0" in convert_bytes_to_string(output.stdout)
         assert "Untracked files:" in convert_bytes_to_string(output.stdout)
         assert "file-1" in convert_bytes_to_string(output.stdout)
         assert "file-2" in convert_bytes_to_string(output.stdout)
@@ -48,8 +48,8 @@ class TestGit(IntegrationTestCase):
         super().create_dummy_file(".gitignore", 100)
         self.git_service.add("git_data/file-0")
         output = execute_command(["git", "status"], capture_output=True)
-        assert f"new file:   git_data/file-0" in convert_bytes_to_string(output.stdout)
-        assert f"new file:   .gitignore" in convert_bytes_to_string(output.stdout)
+        assert "new file:   git_data/file-0" in convert_bytes_to_string(output.stdout)
+        assert "new file:   .gitignore" in convert_bytes_to_string(output.stdout)
 
     def test_commit(self):
         self.git_service.init()
@@ -58,4 +58,3 @@ class TestGit(IntegrationTestCase):
         self.git_service.commit("Commit 1")
         output = execute_command(["git", "log", "--oneline"], capture_output=True)
         assert "Commit 1" in convert_bytes_to_string(output.stdout)
-
